BotSeatableCase class final

A GameRules.botSeatable predicate case.

Inheritance

Constructors

BotSeatableCase({required String name, required Map<String, dynamic> gameConfig, required Map<String, dynamic> botConfig, required bool expected})
const

Properties

botConfig → Map<String, dynamic>
final
expected → bool
final
gameConfig → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The case's name, used as the test name.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited