LifecycleCase class final

Exercises LocalGameRules.applyLifecycle for one trigger.

Inheritance

Constructors

LifecycleCase({required String name, required Map<String, dynamic> config, required Map<String, dynamic> state, required List<int> pending, required LifecycleAction action, required String rngSeed, required ExpectedEnvelope expected})
const

Properties

action LifecycleAction
The engine-constructed payload, already typed.
final
config → Map<String, dynamic>
final
expected ExpectedEnvelope
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The case's name, used as the test name.
finalinherited
pending → List<int>
final
rngSeed → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited