PlayerLimitsCase class final
A GameRules.playerLimits case: the seats one config may be played with.
- Inheritance
-
- Object
- TwinFixtureCase
- PlayerLimitsCase
Constructors
-
PlayerLimitsCase({required String name, required Map<
String, dynamic> config, required PlayerLimits expected}) -
const
Properties
-
config
→ Map<
String, dynamic> -
final
- expected → PlayerLimits
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The case's
name, used as the test name.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited