seat property
int?
seat
final
The bot seat whose stream this is, or null for the transition stream.
Implementation
final int? seat;
The bot seat whose stream this is, or null for the transition stream.
final int? seat;