TranscriptTransition class final

One move of a TranscriptCase: a game action, or a resign.

Constructors

TranscriptTransition({required bool isLifecycle, required int playerIndex, Map<String, dynamic> data = const {}})
const

Properties

data → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
isLifecycle → bool
final
playerIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited