path property
String
path
final
The fixture file this suite was loaded from, for failure messages.
Implementation
final String path;
The fixture file this suite was loaded from, for failure messages.
final String path;