ErrorCode enum

A stable machine code identifying why a request failed.

Inheritance
  • Object
  • Enum
  • ErrorCode

Values

notActive → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'notActive')
notReady → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'notReady')
expired → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'expired')
notPending → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'notPending')
stateUpdated → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'stateUpdated')
invalidPayload → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'invalidPayload')
illegalMove → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'illegalMove')
unknownGame → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'unknownGame')
notJoinable → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'notJoinable')
gameFull → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'gameFull')
alreadyJoined → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'alreadyJoined')
notParticipant → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'notParticipant')
notCreator → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'notCreator')
creatorCannotLeave → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'creatorCannotLeave')
schemaUnsupported → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'schemaUnsupported')
usernameInvalid → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'usernameInvalid')
usernameTaken → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'usernameTaken')
friendsOnly → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'friendsOnly')
registrationRequired → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'registrationRequired')
imageTooLarge → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'imageTooLarge')
unsupportedImageType → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'unsupportedImageType')
rateLimited → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'rateLimited')
unknownDefaultOpenApi → const ErrorCode

A stable machine code identifying why a request failed.

const ErrorCode(r'unknown_default_open_api')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ErrorCode>
A constant List of the values in this enum, in order of their declaration.