Outcome class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

Outcome({required int playerIndex, required OutcomeResultEnum result, required int placement, required int teamIndex, num? score})
Returns a new Outcome instance.
Outcome.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
placement → int
final
playerIndex → int
final
result → OutcomeResultEnum
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → num?
final
teamIndex → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override