InitialStateCase class final
Exercises LocalGameRules.initialState for one config and seat count.
- Inheritance
-
- Object
- TwinFixtureCase
- InitialStateCase
Constructors
-
InitialStateCase({required String name, required Map<
String, dynamic> config, required int playerCount, required String rngSeed, required ExpectedEnvelope expected}) -
const
Properties
-
config
→ Map<
String, dynamic> -
final
- expected → ExpectedEnvelope
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The case's
name, used as the test name.finalinherited - playerCount → int
-
final
- rngSeed → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited