RatingPoolCase class final
A GameRules.ratingPool predicate case.
- Inheritance
-
- Object
- TwinFixtureCase
- RatingPoolCase
Constructors
-
RatingPoolCase({required String name, required GameAccess access, required int? turnSeconds, required int? budgetSeconds, required int? incrementSeconds, required int minPlayers, required int maxPlayers, required Map<
String, dynamic> config, required String? expected}) -
const
Properties
- access → GameAccess
-
final
- budgetSeconds → int?
-
final
-
config
→ Map<
String, dynamic> -
final
- expected → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- incrementSeconds → int?
-
final
- maxPlayers → int
-
final
- minPlayers → int
-
final
- name → String
-
The case's
name, used as the test name.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- turnSeconds → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited