TwinFixtureSuite class
One fixture file's cases, all targeting one schemaVersion unit.
Constructors
-
TwinFixtureSuite({required String path, required int schemaVersion, required List<
TwinFixtureCase> cases}) -
const
Properties
-
cases
→ List<
TwinFixtureCase> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
The fixture file this suite was loaded from, for failure messages.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
The
schemaVersionwhose rules unit every case targets.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited