Rating class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
-
Rating({required String pool, required num mu, required num sigma, required int displayRating, required int updatedAt})
-
Returns a new Rating instance.
-
Rating.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
displayRating
→ int
-
final
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
mu
→ num
-
final
-
pool
→ String
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sigma
→ num
-
final
-
updatedAt
→ int
-
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
-
toString()
→ String
-
A string representation of this object.
override
Operators
-
operator ==(Object other)
→ bool
-
The equality operator.
override